/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2015 Camil Staps <info@camilstaps.nl>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.camilstaps.mandelbrot;

import fractals.MainWindow;

/**
 * Solutions to week 11
 * @author Camil Staps
 */
public class Mandelbrot {
    
    /**
     * MainWindow does the hard work
     * @param args 
     */
    public static void main(String args[]) {
        MainWindow fractal_win = new MainWindow ();
    }
    
    /**
     * Calculate the mandel number up to a certain amount of iterations of the function
     * @param x
     * @param y
     * @param repetitions
     * @return 
     */
    public static int mandelNumber(double x, double y, int repetitions) {
        double x_n = x, y_n = y;
        int n = 0;
        
        while (x_n * x_n + y_n * y_n <= 4 && n <= repetitions) {
            double new_x_n = x_n * x_n - y_n * y_n + x;
            y_n = 2 * x_n * y_n + y;
            x_n = new_x_n;
            n++;
        }
        
        return n;
    }

}